==> ulyxex.0.0.6.with-tinyMce.zip: readme.md <==
Ulyxex version 0.0.6 
====================

Andres Lozano Gallego a.k.a Loz, 2012-2014.
Copyleft: this work is free, you can copy, distribute and modify it under the terms of the Free Art License http://www.artlibre.org

Ulyxex name is inspired by Ulyxes (grec odysseus)
-------------------------------------------------

Ulyxex is a minimal web content generator for people who wants an universal 
interface for all devices, Ulyxex is absolutely compatible with all browsers
since mosaic (1994) to the latest browsers and fully compatible with (lynx).
Ulyxex is also compatible with all smartphone devices.

If you can access internet then you can create and edit your posts.

Features : only what we need and 100% every navigator compatible, 
perfect for console browsing, php/mysql with a lot of programming
oriented objet, html.

I wrote this program for multi-user managment. I used
object-oriented programming in php and mysql.

With this program you can create text articles in separate pages.
This minimum program can be easily modified and enriched, the code is very
readable and understandable. It can be a starting point to learn how to create
php application.

To install this program you must edit the file "config.php" with the settings
in your mysql database and import the file "ulyxex.sql" in the database.
I hope you enjoy this work and you will share your improvements.
This program is licensed under copyleft. You can use, copy, modify and
redistribute it freely.

To log first in :

	login = admin
	
	password = admin
	
Web site [ulyxex.logz.org](http://ulyxex.logz.org)

==> ulyxex.0.0.7.with-tinyMce.zip: readme.md <==
Ulyxex

Andres Lozano Gallego a.k.a Loz, 2012-2014.
Copyleft: this work is free, you can copy, distribute and modify it under the terms of the Free Art License http://www.artlibre.org

Ulyxex name is inspired by Ulyxes (grec odysseus)
-------------------------------------------------

Ulyxex is a minimal web content generator for people who wants an universal 
interface for all devices, Ulyxex is absolutely compatible with all browsers
since mosaic (1994) to the latest browsers and fully compatible with (lynx).
Ulyxex is also compatible with all smartphone devices.

If you can access internet then you can create and edit your posts.

This program follows the "retroweb 1.9" rules of webdesign wrote here http://hyperficiel.com/retroweb/guidelines.html

Features : only what we need and 100% every navigator compatible, 
perfect for console browsing, php/mysql with a lot of programming
oriented objet, html.

I wrote this program for multi-user managment. I used
object-oriented programming in php and mysql.

With this program you can create text articles in separate pages.
This minimum program can be easily modified and enriched, the code is very
readable and understandable. It can be a starting point to learn how to create
php application.

To install this program you must edit the file "config.php" with the settings
in your mysql database and import the file "ulyxex.sql" in the database.
I hope you enjoy this work and you will share your improvements.
This program is licensed under copyleft. You can use, copy, modify and
redistribute it freely.

To log first in :

	login = admin
	
	password = admin
	
Web site [ulyxex.logz.org](http://ulyxex.logz.org)
